SystemOrganization addCategory: #ConfigurationOfNewECompletion!

Object subclass: #ConfigurationOfNewECompletion
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfNewECompletion'!

!ConfigurationOfNewECompletion commentStamp: '<historical>' prior: 0!
A configuration for a cleaned version of ECompletion starting to work on Pharo1.4. 

((Smalltalk globals at: #ConfigurationOfNewECompletion) project version: '1.0') load

(ConfigurationOfNewECompletion project version: #stable) load 
!

!ConfigurationOfNewECompletion classSide methodsFor: 'private' stamp: ''!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfNewECompletion classSide methodsFor: 'private' stamp: ''!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.15"
			self bootstrapPackage: 'Gofer-lr.83' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load latest version of Metacello, load a specific version if desired"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #loadLatestVersion ]! !

!ConfigurationOfNewECompletion classSide methodsFor: 'metacello tool support' stamp: 'StephaneDucasse 3/25/2012 22:31'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfNewECompletion classSide methodsFor: 'metacello tool support' stamp: ''!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfNewECompletion classSide methodsFor: 'metacello tool support' stamp: ''!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfNewECompletion classSide methodsFor: 'accessing' stamp: ''!
project

	^self new project! !

!ConfigurationOfNewECompletion methodsFor: 'baseline' stamp: 'StephaneDucasse 3/25/2012 22:29'!
baseline10: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
	].
		
	spec for: #pharo do: [
		spec repository: 'http://ss3.gemstone.com/ss/NEC'.
		spec package: 'NECompletion'.	
		spec
			group: 'default' with: #('NECompletion' );
			group: 'Core' with: #( 'NECompletion'  );
			yourself.	
	].
	! !

!ConfigurationOfNewECompletion methodsFor: 'symbolic versions' stamp: 'EstebanLorenzano 4/12/2012 17:24'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.2'.
! !

!ConfigurationOfNewECompletion methodsFor: 'accessing' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		project ]! !

!ConfigurationOfNewECompletion methodsFor: 'symbolic' stamp: 'EstebanLorenzano 4/12/2012 17:25'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'pharo1.4.x' version: '1.3'.! !

!ConfigurationOfNewECompletion methodsFor: 'versions' stamp: 'StephaneDucasse 3/25/2012 22:53'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #pharo do: [		
		spec blessing: #release.
		spec package: 'NECompletion' with: 'NECompletion-StephaneDucasse.8'.	
	].! !

!ConfigurationOfNewECompletion methodsFor: 'versions' stamp: 'EstebanLorenzano 4/11/2012 17:58'!
version11: spec
	<version: '1.1' imports: #('1.0-baseline' )>

	spec for: #'pharo' do: [
		spec blessing: #'release'.
		spec package: 'NECompletion' with: 'NECompletion-EstebanLorenzano.9'. ].
! !

!ConfigurationOfNewECompletion methodsFor: 'versions' stamp: 'EstebanLorenzano 4/12/2012 13:51'!
version12: spec
	<version: '1.2' imports: #('1.0-baseline' )>

	spec for: #'pharo' do: [
		spec blessing: #'release'.
		spec package: 'NECompletion' with: 'NECompletion-EstebanLorenzano.10'. ].
! !

!ConfigurationOfNewECompletion methodsFor: 'versions' stamp: 'EstebanLorenzano 4/12/2012 17:25'!
version13: spec
	<version: '1.3' imports: #('1.0-baseline' )>

	spec for: #'pharo' do: [
		spec blessing: #'release'.
		spec package: 'NECompletion' with: 'NECompletion-EstebanLorenzano.11'. ].
! !
